==> base-connectivity-sdk-0.5.45-sources.jar: com/segway/robot/sdk/baseconnectivity/Message.java <==
package com.segway.robot.sdk.baseconnectivity;

import com.segway.robot.sdk.base.time.StampedData;

/**
 * Message to be sent when {@link MessageConnection} is created. It is a base class for {@code BufferMessage}
 * and {@code StringMessage} implementations. It is recommended that when sending messages,
 * use BufferMessage/StringMessage instead of using Message directly.
 *
 * @param <T> the message content which can be byte[] or String.
 */
public class Message<T> implements StampedData {

    private T mContent;
    private long mTimestamp = 0;
    private static int mId = 0;

    /**
     * Create an empty {@code Message}.
     */
    public Message() {
        createId();
    }

    protected Message(long timestamp, T content, int id) {
        mTimestamp = timestamp;
        mContent = content;
        mId = id;
    }

    /**
     * Create an empty {@code Message} with the message content initialized.
     *
     * @param content the content of the Message to be sent.
     */
    public Message(T content) {
        createId();
        mContent = content;
    }

    /**
     * Get the message ID.
     *
     * @return the ID of the Message to be sent.
     */
    public int getId() {
        return mId;
    }

    /**
     * Get the timestamp when the Message is sent.
     *
     * @return the timestamp when the Message is sent.
     */
    @Override
    public long getTimestamp() {
        return mTimestamp;
    }

    /**
     * Set the message content.
     *
     * @param message the content of the message to be set for Message.
     */
    public void setContent(T message) {
        mContent = message;
    }

    /**
     * Get the message content.
     *
     * @return the content of the Message which can be byte[] or String.
     */
    public T getContent() {
        return mContent;
    }

    private static synchronized long createId() {
        mId++;
        return mId;
    }

    @Override
    public long diff(StampedData source) {
        if (source == null) {
            throw new IllegalArgumentException("StampedData can't be null!");
        }
        return mTimestamp - source.getTimestamp();
    }
}

==> base-connectivity-sdk-1.0-sources.jar: com/segway/robot/sdk/baseconnectivity/Message.java <==
package com.segway.robot.sdk.baseconnectivity;

/**
 * Message to be sent when {@link MessageConnection} is created. It is a base class for {@code BufferMessage}
 * and {@code StringMessage} implementations. It is recommended that when sending messages,
 * use BufferMessage/StringMessage instead of using Message directly.
 *
 * @param <T> the message content which can be byte[] or String.
 */
public class Message<T> {

    private T mContent;
    private long mTimestamp = 0;
    private static int mId = 0;

    /**
     * Create an empty {@code Message}.
     */
    public Message() {
        mId++;
    }

    protected Message(long timestamp, T content, int id) {
        mTimestamp = timestamp;
        mContent = content;
        mId = id;
    }

    /**
     * Create an empty {@code Message} with the message content initialized.
     *
     * @param content the content of the Message to be sent.
     */
    public Message(T content) {
        mId++;
        mContent = content;
    }

    /**
     * Get the message ID.
     *
     * @return the ID of the Message to be sent.
     */
    public int getId() {
        return mId;
    }

    /**
     * Get the timestamp when the Message is sent.
     *
     * @return the timestamp when the Message is sent.
     */
    public long getTimestampSent() {
        return mTimestamp;
    }

    /**
     * Set the message content.
     *
     * @param message the content of the message to be set for Message.
     */
    public void setContent(T message) {
        mContent = message;
    }

    /**
     * Get the message content.
     *
     * @return the content of the Message which can be byte[] or String.
     */
    public T getContent() {
        return mContent;
    }
}
